# PyANSI3

PyANSI3 is a simple Python library to apply ANSI colors to text in the terminal. It allows you to easily print colored text directly in your terminal by using placeholders like `{red}`, `{green}`, etc.

## Full colors

        black
        red
        green
        yellow
        blue
        magenta
        cyan
        white
        reset
        bold
        underline
        black_bg
        red_bg
        green_bg
        yellow_bg
        blue_bg
        magenta_bg
        cyan_bg
        white_bg

### Installation

You can install PyANSI3 via pip:

pip install py-ansi3
